server

package
v0.0.0-...-e896590 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 5, 2018 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Server

type Server struct {
	// Router is a mux.Router that registers the handlers for the different OSB
	// API operations.
	Router *mux.Router
}

func New

func New(api *rest.APISurface) *Server

New creates a new Router and registers all the necessary endpoints and handlers.

func (*Server) Run

func (s *Server) Run(ctx context.Context, addr string) error

Run creates the HTTP handler and begins to listen on the specified address.

func (*Server) RunTLS

func (s *Server) RunTLS(ctx context.Context, addr string, cert string, key string) error

RunTLS creates the HTTPS handler based on the certifications that were passed and begins to listen on the specified address.

Jump to