Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
// Router is a mux.Router that registers the handlers for the different OSB
// API operations.
Router *mux.Router
}
func New ¶
func New(api *rest.APISurface) *Server
New creates a new Router and registers all the necessary endpoints and handlers.
Click to show internal directories.
Click to hide internal directories.